import{geoPath as n,geoAlbers as u,geoAlbersUsa as g,geoAzimuthalEqualArea as p,geoAzimuthalEquidistant as m,geoConicConformal as h,geoConicEqualArea as d,geoConicEquidistant as f,geoEqualEarth as E,geoEquirectangular as q,geoGnomonic as j,geoIdentity as A,geoMercator as z,geoNaturalEarth1 as b,geoOrthographic as w,geoStereographic as P,geoTransverseMercator as x}from"/-/d3-geo@v3.0.1-kwyelOm8gApBxT2oVVB9/dist=es2020,mode=imports,min/optimized/d3-geo.js";import{geoMollweide as C}from"/-/d3-geo-projection@v4.0.0-5Hhxj2zKHEqWYAQIFo3r/dist=es2020,mode=imports,min/optimized/d3-geo-projection.js";const v=n(),c=["clipAngle","clipExtent","scale","translate","center","rotate","parallels","precision","reflectX","reflectY","coefficient","distance","fraction","lobes","parallel","radius","ratio","spacing","tilt"];function y(e,r){return function s(){const o=r();return o.type=e,o.path=n().projection(o),o.copy=o.copy||function(){const i=s();return c.forEach(a=>{o[a]&&i[a](o[a]())}),i.path.pointRadius(o.path.pointRadius()),i},o}}function l(e,r){if(!e||typeof e!="string")throw new Error("Projection type must be a name string.");return e=e.toLowerCase(),arguments.length>1?(t[e]=y(e,r),this):t[e]||null}function M(e){return e&&e.path||v}const t={albers:u,albersusa:g,azimuthalequalarea:p,azimuthalequidistant:m,conicconformal:h,conicequalarea:d,conicequidistant:f,equalEarth:E,equirectangular:q,gnomonic:j,identity:A,mercator:z,mollweide:C,naturalEarth1:b,orthographic:w,stereographic:P,transversemercator:x};for(const e in t)l(e,t[e]);export{M as getProjectionPath,l as projection,c as projectionProperties};export default null;
