/*
 * Skypack CDN - vega-lite@5.0.0
 * Remove "min" from url for additional help & instructions.
 */

export * from '/-/vega-lite@v5.0.0-pmBUeju4pfpuhRqteP34/dist=es2020,mode=imports,min/optimized/vega-lite.js';
export {default} from '/-/vega-lite@v5.0.0-pmBUeju4pfpuhRqteP34/dist=es2020,mode=imports,min/optimized/vega-lite.js';
