/*
 * Skypack CDN - vega-lite@4.17.0
 * Remove "min" from url for additional help & instructions.
 */

export * from '/-/vega-lite@v4.17.0-ycT3UrEO81NWOPVKlbjt/dist=es2020,mode=imports,min/optimized/vega-lite.js';
export {default} from '/-/vega-lite@v4.17.0-ycT3UrEO81NWOPVKlbjt/dist=es2020,mode=imports,min/optimized/vega-lite.js';

// Perf Optimization: Preload Deep Imports
import "/-/vega-util@v1.16.1-QtdV0YLGVmjtkzFiPbzm/dist=es2020,mode=imports,min/optimized/vega-util.js";
import "/-/clone@v2.1.2-inH2VLNzDGiYU9HUWyZM/dist=es2020,mode=imports,min/optimized/clone.js";
import "/-/fast-deep-equal@v3.1.3-ysejKs1WDEDPxUJhgGoP/dist=es2020,mode=imports,min/optimized/fast-deep-equal.js";
import "/-/fast-json-stable-stringify@v2.1.0-HLgsuOtxPikt0pw16nth/dist=es2020,mode=imports,min/optimized/fast-json-stable-stringify.js";
import "/-/vega-event-selector@v2.0.6-fTsDie9ajW0bqk8q646l/dist=es2020,mode=imports,min/optimized/vega-event-selector.js";
import "/-/vega-expression@v3.0.1-A7mhk5wjrSNOpQiSL1LP/dist=es2020,mode=imports,min/optimized/vega-expression.js";
import "/-/vega-util@v1.17.0-uRskU0IBL2vWCP4Va8OC/dist=es2020,mode=imports,min/optimized/vega-util.js";