/*
 * Skypack CDN - vega@5.22.1
 * Remove "min" from url for additional help & instructions.
 */

export * from '/-/vega@v5.22.1-1GozmoxV3boOt3w4YuEn/dist=es2020,mode=imports,min/optimized/vega.js';
export {default} from '/-/vega@v5.22.1-1GozmoxV3boOt3w4YuEn/dist=es2020,mode=imports,min/optimized/vega.js';
