var V={},N={},A=34,R=10,E=13;function y(r){return new Function("d","return {"+r.map(function(o,n){return JSON.stringify(o)+": d["+n+'] || ""'}).join(",")+"}")}function Z(r,o){var n=y(r);return function(a,f){return o(n(a),f,r)}}function I(r){var o=Object.create(null),n=[];return r.forEach(function(a){for(var f in a)f in o||n.push(o[f]=f)}),n}function u(r,o){var n=r+"",a=n.length;return a<o?new Array(o-a+1).join(0)+n:n}function H(r){return r<0?"-"+u(-r,6):r>9999?"+"+u(r,6):u(r,4)}function L(r){var o=r.getUTCHours(),n=r.getUTCMinutes(),a=r.getUTCSeconds(),f=r.getUTCMilliseconds();return isNaN(r)?"Invalid Date":H(r.getUTCFullYear())+"-"+u(r.getUTCMonth()+1,2)+"-"+u(r.getUTCDate(),2)+(f?"T"+u(o,2)+":"+u(n,2)+":"+u(a,2)+"."+u(f,3)+"Z":a?"T"+u(o,2)+":"+u(n,2)+":"+u(a,2)+"Z":n||o?"T"+u(o,2)+":"+u(n,2)+"Z":"")}function j(r){var o=new RegExp('["'+r+`
\r]`),n=r.charCodeAt(0);function a(t,e){var c,i,s=f(t,function(p,m){if(c)return c(p,m-1);i=p,c=e?Z(p,e):y(p)});return s.columns=i||[],s}function f(t,e){var c=[],i=t.length,s=0,p=0,m,F=i<=0,d=!1;t.charCodeAt(i-1)===R&&--i,t.charCodeAt(i-1)===E&&--i;function B(){if(F)return N;if(d)return d=!1,V;var T,g=s,h;if(t.charCodeAt(g)===A){for(;s++<i&&t.charCodeAt(s)!==A||t.charCodeAt(++s)===A;);return(T=s)>=i?F=!0:(h=t.charCodeAt(s++))===R?d=!0:h===E&&(d=!0,t.charCodeAt(s)===R&&++s),t.slice(g+1,T-1).replace(/""/g,'"')}for(;s<i;){if((h=t.charCodeAt(T=s++))===R)d=!0;else if(h===E)d=!0,t.charCodeAt(s)===R&&++s;else if(h!==n)continue;return t.slice(g,T)}return F=!0,t.slice(g,i)}for(;(m=B())!==N;){for(var C=[];m!==V&&m!==N;)C.push(m),m=B();if(e&&(C=e(C,p++))==null)continue;c.push(C)}return c}function U(t,e){return t.map(function(c){return e.map(function(i){return w(c[i])}).join(r)})}function O(t,e){return e==null&&(e=I(t)),[e.map(w).join(r)].concat(U(t,e)).join(`
`)}function M(t,e){return e==null&&(e=I(t)),U(t,e).join(`
`)}function P(t){return t.map(D).join(`
`)}function D(t){return t.map(w).join(r)}function w(t){return t==null?"":t instanceof Date?L(t):o.test(t+="")?'"'+t.replace(/"/g,'""')+'"':t}return{parse:a,parseRows:f,format:O,formatBody:M,formatRows:P,formatRow:D,formatValue:w}}var v=j(","),S=v.parse,Y=v.parseRows,z=v.format,J=v.formatBody,Q=v.formatRows,W=v.formatRow,$=v.formatValue,l=j("	"),k=l.parse,q=l.parseRows,G=l.format,K=l.formatBody,X=l.formatRows,_=l.formatRow,b=l.formatValue;function x(r){for(var o in r){var n=r[o].trim(),a,f;if(!n)n=null;else if(n==="true")n=!0;else if(n==="false")n=!1;else if(n==="NaN")n=NaN;else if(!isNaN(a=+n))n=a;else if(f=n.match(/^([-+]\d{2})?\d{4}(-\d{2}(-\d{2})?)?(T\d{2}:\d{2}(:\d{2}(\.\d{3})?)?(Z|[-+]\d{2}:\d{2})?)?$/))rr&&!!f[4]&&!f[7]&&(n=n.replace(/-/g,"/").replace(/T/," ")),n=new Date(n);else continue;r[o]=n}return r}const rr=new Date("2019-01-01T00:00").getHours()||new Date("2019-07-01T00:00").getHours();export{x as autoType,z as csvFormat,J as csvFormatBody,W as csvFormatRow,Q as csvFormatRows,$ as csvFormatValue,S as csvParse,Y as csvParseRows,j as dsvFormat,G as tsvFormat,K as tsvFormatBody,_ as tsvFormatRow,X as tsvFormatRows,b as tsvFormatValue,k as tsvParse,q as tsvParseRows};export default null;
