import{tickStep as H}from"/-/d3-array@v3.1.1-Ibshj34oOmCw8da1RLSW/dist=es2020,mode=imports,min/optimized/d3-array.js";import{formatSpecifier as N,precisionFixed as V,precisionRound as q,precisionPrefix as Q,formatLocale as $,format as J,formatPrefix as X}from"/-/d3-format@v3.1.0-D5wAD2odDPNNWsKloKgL/dist=es2020,mode=imports,min/optimized/d3-format.js";import{SECONDS as P,MINUTES as I,HOURS as S,DATE as p,WEEK as O,MONTH as v,QUARTER as y,YEAR as M,MILLISECONDS as _,DAY as tt,timeInterval as rt,utcInterval as et}from"/-/vega-time@v2.1.0-LVGYZzfDGZrYRhsP6b35/dist=es2020,mode=imports,min/optimized/vega-time.js";import{isString as k,extend as ot,error as w,isObject as it}from"/-/vega-util@v1.17.0-uRskU0IBL2vWCP4Va8OC/dist=es2020,mode=imports,min/optimized/vega-util.js";import{timeFormat as nt,timeParse as mt,utcFormat as at,utcParse as ut,timeFormatLocale as st}from"/-/d3-time-format@v4.1.0-f8eZV7eLtGIxvK8uvO3o/dist=es2020,mode=imports,min/optimized/d3-time-format.js";function f(t){const e={};return r=>e[r]||(e[r]=t(r))}function ct(t,e){return r=>{const o=t(r),n=o.indexOf(e);if(n<0)return o;let a=ft(o,n);const m=a<o.length?o.slice(a):"";for(;--a>n;)if(o[a]!=="0"){++a;break}return o.slice(0,a)+m}}function ft(t,e){let r=t.lastIndexOf("e"),o;if(r>0)return r;for(r=t.length;--r>e;)if(o=t.charCodeAt(r),o>=48&&o<=57)return r+1}function z(t){const e=f(t.format),r=t.formatPrefix;return{format:e,formatPrefix:r,formatFloat(o){const n=N(o||",");if(n.precision==null){n.precision=12;switch(n.type){case"%":n.precision-=2;break;case"e":n.precision-=1;break}return ct(e(n),e(".1f")(1)[1])}else return e(n)},formatSpan(o,n,a,m){m=N(m??",f");const s=H(o,n,a),c=Math.max(Math.abs(o),Math.abs(n));let u;if(m.precision==null)switch(m.type){case"s":return isNaN(u=Q(s,c))||(m.precision=u),r(m,c);case"":case"e":case"g":case"p":case"r":{isNaN(u=q(s,c))||(m.precision=u-(m.type==="e"));break}case"f":case"%":{isNaN(u=V(s))||(m.precision=u-(m.type==="%")*2);break}}return e(m)}}}let L;g();function g(){return L=z({format:J,formatPrefix:X})}function h(t){return z($(t))}function l(t){return arguments.length?L=h(t):L}function E(t,e,r){r=r||{},it(r)||w("Invalid time multi-format specifier: ".concat(r));const o=e(P),n=e(I),a=e(S),m=e(p),s=e(O),c=e(v),u=e(y),A=e(M),C=t(r[_]||".%L"),T=t(r[P]||":%S"),Y=t(r[I]||"%I:%M"),K=t(r[S]||"%I %p"),U=t(r[p]||r[tt]||"%a %d"),W=t(r[O]||"%b %d"),Z=t(r[v]||"%B"),B=t(r[y]||"%B"),G=t(r[M]||"%Y");return i=>(o(i)<i?C:n(i)<i?T:a(i)<i?Y:m(i)<i?K:c(i)<i?s(i)<i?U:W:A(i)<i?u(i)<i?Z:B:G)(i)}function R(t){const e=f(t.format),r=f(t.utcFormat);return{timeFormat:o=>k(o)?e(o):E(e,rt,o),utcFormat:o=>k(o)?r(o):E(r,et,o),timeParse:f(t.parse),utcParse:f(t.utcParse)}}let F;b();function b(){return F=R({format:nt,parse:mt,utcFormat:at,utcParse:ut})}function x(t){return R(st(t))}function d(t){return arguments.length?F=x(t):F}const D=(t,e)=>ot({},t,e);function lt(t,e){const r=t?h(t):l(),o=e?x(e):d();return D(r,o)}function j(t,e){const r=arguments.length;return r&&r!==2&&w("defaultLocale expects either zero or two arguments."),r?D(l(t),d(e)):D(l(),d())}function dt(){return g(),b(),j()}export{j as defaultLocale,lt as locale,l as numberFormatDefaultLocale,h as numberFormatLocale,dt as resetDefaultLocale,g as resetNumberFormatDefaultLocale,b as resetTimeFormatDefaultLocale,d as timeFormatDefaultLocale,x as timeFormatLocale};export default null;
